// Natif modules
import { ServiceWorkerModule } from '@angular/service-worker';
import { BrowserModule } from '@angular/platform-browser';
import { NgModule } from '@angular/core';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { RouterModule } from '@angular/router';

// Modules
import { CoreModule } from './share/modules/core.module';

// components
import { AppComponent } from './app.component';

// Routing
import { APP_ROUTING } from './app.routing';

// ngrx
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';
import { StoreDevtoolsModule } from '@ngrx/store-devtools';
import { environment } from 'src/environments/environment';
import { reducersMap } from './share/store';
import { AuthEffects } from './share/store/effects/auth.effects';
import { WelcomeComponent } from './components/welcome/welcome.component';

@NgModule({
  declarations: [AppComponent, WelcomeComponent],
  imports: [
		BrowserModule,
		BrowserAnimationsModule,
		RouterModule.forRoot(APP_ROUTING),
		StoreModule.forRoot(reducersMap),
		EffectsModule.forRoot([AuthEffects]),
		StoreDevtoolsModule.instrument({
			name: 'Ngrx',
			logOnly: environment.production
		}),
		CoreModule,
		ServiceWorkerModule.register('ngsw-worker.js', { enabled: environment.production })
  ],
  bootstrap: [AppComponent]
})
export class AppModule { }
